@@ -11,7 +11,7 @@ use std::net::SocketAddr;
 
 #[rpc(client, server, namespace = "foo")]
 pub trait Rpc {
-	#[method(name = "foo", aliases = "fooAlias, Other")]
+	#[method(name = "foo", aliases = ["fooAlias", "Other"])]
 	async fn async_method(&self, param_a: u8, param_b: String) -> RpcResult<u16>;
 
 	#[method(name = "optional_params")]
@@ -29,8 +29,13 @@ pub trait Rpc {
 	#[subscription(name = "sub", item = String)]
 	fn sub(&self) -> RpcResult<()>;
 
-	#[subscription(name = "echo", aliases = "ECHO", item = u32, unsubscribe_aliases = "NotInterested, listenNoMore")]
+	#[subscription(name = "echo", aliases = ["ECHO"], item = u32, unsubscribe_aliases = ["NotInterested", "listenNoMore"])]
 	fn sub_with_params(&self, val: u32) -> RpcResult<()>;
+
+	// This will send data to subscribers with the `method` field in the JSON payload set to `foo_subscribe_override`
+	// because it's in the `foo` namespace.
+	#[subscription(name = "subscribe_method" => "subscribe_override", item = u32)]
+	fn sub_with_override_notif_method(&self) -> RpcResult<()>;
 }
 
 pub struct RpcServerImpl;
@@ -68,6 +73,10 @@ impl RpcServer for RpcServerImpl {
 		sink.send(&val)?;
 		sink.send(&val)
 	}
+
+	fn sub_with_override_notif_method(&self, mut sink: SubscriptionSink) -> RpcResult<()> {
+		sink.send(&1)
+	}
 }
 
 pub async fn websocket_server() -> SocketAddr {
@@ -102,4 +111,8 @@ async fn main() {
 	assert_eq!(first_recv, Some("Response_A".to_string()));
 	let second_recv = sub.next().await.unwrap();
 	assert_eq!(second_recv, Some("Response_B".to_string()));
+
+	let mut sub = client.sub_with_override_notif_method().await.unwrap();
+	let recv = sub.next().await.unwrap();
+	assert_eq!(recv, Some(1));
 }
